==> kftpgrabber-trinity_14.0.10.orig.tar.xz: kftpgrabber-trinity-14.0.10/kftpgrabber/src/widgets/configfilter.h <==
/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2005 by the KFTPGrabber developers
 * Copyright (C) 2003-2005 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Steet, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 *
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
 
#ifndef KFTPWIDGETSCONFIGFILTER_H
#define KFTPWIDGETSCONFIGFILTER_H

#include <ntqwidget.h>
#include <kdialogbase.h>
#include <knuminput.h>
#include <ntqradiobutton.h>
#include <ntqvaluelist.h>

// Layouts
#include "ui/config_filters.h"

namespace KFTPWidgets {

class FilterEditor;

/**
 * Filter related configuration dialog.
 *
 * @author Jernej Kos
 */
class ConfigFilter : public TQWidget
{
Q_OBJECT
public:
    ConfigFilter(TQWidget *parent = 0, const char *name = 0);
    
    void saveSettings();
    void loadSettings();
private:
    void asciiLoadExtensions();
    TQStringList asciiToStringList();

    FilterEditor *m_filterEditor;
    ConfigFilterLayout *m_editorLayout;
private slots:
    void slotAddAscii();
    void slotRemoveAscii();
};

}

#endif

==> kftpgrabber-trinity_14.0.12.orig.tar.xz: kftpgrabber-trinity-14.0.12/kftpgrabber/src/widgets/configfilter.h <==
/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2005 by the KFTPGrabber developers
 * Copyright (C) 2003-2005 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Steet, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 *
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
 
#ifndef KFTPWIDGETSCONFIGFILTER_H
#define KFTPWIDGETSCONFIGFILTER_H

#include <tqwidget.h>
#include <kdialogbase.h>
#include <knuminput.h>
#include <tqradiobutton.h>
#include <tqvaluelist.h>

// Layouts
#include "ui/config_filters.h"

namespace KFTPWidgets {

class FilterEditor;

/**
 * Filter related configuration dialog.
 *
 * @author Jernej Kos
 */
class ConfigFilter : public TQWidget
{
Q_OBJECT
public:
    ConfigFilter(TQWidget *parent = 0, const char *name = 0);
    
    void saveSettings();
    void loadSettings();
private:
    void asciiLoadExtensions();
    TQStringList asciiToStringList();

    FilterEditor *m_filterEditor;
    ConfigFilterLayout *m_editorLayout;
private slots:
    void slotAddAscii();
    void slotRemoveAscii();
};

}

#endif
